================================================================================
snapshot-selenium
================================================================================

.. image:: https://api.travis-ci.org/pyecharts/snapshot-selenium.svg
   :target: http://travis-ci.org/pyecharts/snapshot-selenium

.. image:: https://codecov.io/github/pyecharts/snapshot-selenium/coverage.png
   :target: https://codecov.io/github/pyecharts/snapshot-selenium


.. image:: https://readthedocs.org/projects/snapshot-selenium/badge/?version=latest
   :target: http://snapshot-selenium.readthedocs.org/en/latest/


Installation
================================================================================


You can install snapshot-selenium via pip:

.. code-block:: bash

    $ pip install snapshot-selenium


or clone it and install it:

.. code-block:: bash

    $ git clone https://github.com/pyecharts/snapshot-selenium.git
    $ cd snapshot-selenium
    $ python setup.py install
